@@ -47,4 +47,11 @@
 #define SONYPI_IOCGBLUE         _IOR('v', 8, __u8)
 #define SONYPI_IOCSBLUE         _IOW('v', 9, __u8)
 
+/* get/set fan state on/off */
+#define SONYPI_IOCGFAN          _IOR('v', 10, __u8)
+#define SONYPI_IOCSFAN          _IOW('v', 11, __u8)
+
+/* get temperature (C) */
+#define SONYPI_IOCGTEMP         _IOR('v', 12, __u8)
+
 #endif /* _SPICCTRL_H_ */
